PoolConnection

Struct PoolConnection 

pub struct PoolConnection<DB>
where DB: Database,
{ /* private fields */ }
A connection managed by a Pool.

Will be returned to the pool on-drop.

Implementations



impl<DB> PoolConnection<DB>
where DB: Database,

pub async fn close(self) -> Result<(), Error>

Close this connection, allowing the pool to open a replacement.

Equivalent to calling .detach() then .close(), but the connection permit is retained for the duration so that the pool may not exceed max_connections.

pub fn close_on_drop(&mut self)

Close this connection on-drop, instead of returning it to the pool.

May be used in cases where waiting for the .close() call to complete is unacceptable, but you still want the connection to be closed gracefully so that the server can clean up resources.

pub fn detach(self) -> <DB as Database>::Connection

Detach this connection from the pool, allowing it to open a replacement.

Note that if your application uses a single shared pool, this effectively lets the application exceed the max_connections setting.

If min_connections is nonzero, a task will be spawned to replace this connection.

If you want the pool to treat this connection as permanently checked-out, use .leak() instead.

pub fn leak(self) -> <DB as Database>::Connection

Detach this connection from the pool, treating it as permanently checked-out.

This effectively will reduce the maximum capacity of the pool by 1 every time it is used.

If you don’t want to impact the pool’s capacity, use .detach() instead.